# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/resource.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"yandex/cloud/cdn/v1/resource.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"$\n\x12SecondaryHostnames\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xac\x03\n\x08Resource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\r\n\x05\x63name\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\x12\x35\n\x07options\x18\x07 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12\x1b\n\x13secondary_hostnames\x18\x08 \x03(\t\x12\x17\n\x0forigin_group_id\x18\t \x01(\x03\x12\x19\n\x11origin_group_name\x18\n \x01(\t\x12<\n\x0forigin_protocol\x18\x0b \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12<\n\x0fssl_certificate\x18\x0c \x01(\x0b\x32#.yandex.cloud.cdn.v1.SSLCertificate\"\xef\x1c\n\x0fResourceOptions\x12\x46\n\rdisable_cache\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12S\n\x13\x65\x64ge_cache_settings\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings\x12P\n\x16\x62rowser_cache_settings\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.cdn.v1.ResourceOptions.Int64Option\x12R\n\x12\x63\x61\x63he_http_headers\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12U\n\x14query_params_options\x18\x05 \x01(\x0b\x32\x37.yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions\x12>\n\x05slice\x18\x06 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12T\n\x13\x63ompression_options\x18\x07 \x01(\x0b\x32\x37.yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions\x12N\n\x10redirect_options\x18\x08 \x01(\x0b\x32\x34.yandex.cloud.cdn.v1.ResourceOptions.RedirectOptions\x12\x46\n\x0chost_options\x18\t \x01(\x0b\x32\x30.yandex.cloud.cdn.v1.ResourceOptions.HostOptions\x12M\n\x0estatic_headers\x18\n \x01(\x0b\x32\x35.yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption\x12\x44\n\x04\x63ors\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12\x45\n\x05stale\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12T\n\x14\x61llowed_http_methods\x18\r \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12P\n\x17proxy_cache_methods_set\x18\x0e \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12S\n\x1a\x64isable_proxy_force_ranges\x18\x0f \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12U\n\x16static_request_headers\x18\x10 \x01(\x0b\x32\x35.yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption\x12M\n\x12\x63ustom_server_name\x18\x11 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.StringOption\x12\x46\n\rignore_cookie\x18\x12 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12\x43\n\x07rewrite\x18\x13 \x01(\x0b\x32\x32.yandex.cloud.cdn.v1.ResourceOptions.RewriteOption\x1a,\n\nBoolOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x08\x1a.\n\x0cStringOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\x1a-\n\x0bInt64Option\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x03\x1a\x33\n\x11StringsListOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x03(\t\x1a\xa2\x01\n\x10StringsMapOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12O\n\x05value\x18\x02 \x03(\x0b\x32@.yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xb5\x01\n\x0c\x43\x61\x63hingTimes\x12\x14\n\x0csimple_value\x18\x01 \x01(\x03\x12Z\n\rcustom_values\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.CustomValuesEntry\x1a\x33\n\x11\x43ustomValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x93\x01\n\x11\x45\x64geCacheSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.CachingTimesH\x00\x12\x17\n\rdefault_value\x18\x03 \x01(\x03H\x00\x42\x10\n\x0evalues_variant\x1a\xa9\x03\n\x17StringVariableMapOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12V\n\x05value\x18\x02 \x03(\x0b\x32G.yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.ValueEntry\x1a\xac\x01\n\x0bOneofString\x12\x42\n\x05value\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.StringOptionH\x00\x12H\n\x06values\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x42\x0f\n\rstring_option\x1av\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12W\n\x05value\x18\x02 \x01(\x0b\x32H.yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.OneofString:\x02\x38\x01\x1a\xb0\x02\n\x12QueryParamsOptions\x12N\n\x13ignore_query_string\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12X\n\x16query_params_whitelist\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x12X\n\x16query_params_blacklist\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x42\x16\n\x14query_params_variant\x1a\xcb\x01\n\x0fRedirectOptions\x12Q\n\x16redirect_http_to_https\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12Q\n\x16redirect_https_to_http\x18\x02 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x42\x12\n\x10redirect_variant\x1a\xb0\x01\n\x0bHostOptions\x12\x41\n\x04host\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.StringOptionH\x00\x12N\n\x13\x66orward_host_header\x18\x02 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x42\x0e\n\x0chost_variant\x1a\x92\x02\n\x12\x43ompressionOptions\x12K\n\x10\x66\x65tch_compressed\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12\x42\n\x07gzip_on\x18\x02 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12T\n\x12\x62rotli_compression\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x42\x15\n\x13\x63ompression_variant\x1a^\n\rRewriteOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12.\n\x04\x66lag\x18\x03 \x01(\x0e\x32 .yandex.cloud.cdn.v1.RewriteFlag\"\x84\x01\n\x14SSLTargetCertificate\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yandex.cloud.cdn.v1.SSLCertificateType\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SSLCertificateData\"\xb9\x01\n\x0eSSLCertificate\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yandex.cloud.cdn.v1.SSLCertificateType\x12\x39\n\x06status\x18\x02 \x01(\x0e\x32).yandex.cloud.cdn.v1.SSLCertificateStatus\x12\x35\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SSLCertificateData\"m\n\x12SSLCertificateData\x12\x37\n\x02\x63m\x18\x01 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLCertificateCMDataH\x00\x42\x1e\n\x1cssl_certificate_data_variant\"\"\n\x14SSLCertificateCMData\x12\n\n\x02id\x18\x01 \x01(\t*Q\n\x0eOriginProtocol\x12\x1f\n\x1bORIGIN_PROTOCOL_UNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\x12\t\n\x05MATCH\x10\x03*]\n\x0bRewriteFlag\x12\x1c\n\x18REWRITE_FLAG_UNSPECIFIED\x10\x00\x12\x08\n\x04LAST\x10\x01\x12\t\n\x05\x42REAK\x10\x02\x12\x0c\n\x08REDIRECT\x10\x03\x12\r\n\tPERMANENT\x10\x04*h\n\x12SSLCertificateType\x12$\n SSL_CERTIFICATE_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ONT_USE\x10\x01\x12\x16\n\x12LETS_ENCRYPT_GCORE\x10\x02\x12\x06\n\x02\x43M\x10\x03*W\n\x14SSLCertificateStatus\x12&\n\"SSL_CERTIFICATE_STATUS_UNSPECIFIED\x10\x00\x12\t\n\x05READY\x10\x01\x12\x0c\n\x08\x43REATING\x10\x02\x42V\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ORIGINPROTOCOL = _descriptor.EnumDescriptor(
  name='OriginProtocol',
  full_name='yandex.cloud.cdn.v1.OriginProtocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_PROTOCOL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MATCH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4729,
  serialized_end=4810,
)
_sym_db.RegisterEnumDescriptor(_ORIGINPROTOCOL)

OriginProtocol = enum_type_wrapper.EnumTypeWrapper(_ORIGINPROTOCOL)
_REWRITEFLAG = _descriptor.EnumDescriptor(
  name='RewriteFlag',
  full_name='yandex.cloud.cdn.v1.RewriteFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REWRITE_FLAG_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BREAK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDIRECT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4812,
  serialized_end=4905,
)
_sym_db.RegisterEnumDescriptor(_REWRITEFLAG)

RewriteFlag = enum_type_wrapper.EnumTypeWrapper(_REWRITEFLAG)
_SSLCERTIFICATETYPE = _descriptor.EnumDescriptor(
  name='SSLCertificateType',
  full_name='yandex.cloud.cdn.v1.SSLCertificateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SSL_CERTIFICATE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DONT_USE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LETS_ENCRYPT_GCORE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4907,
  serialized_end=5011,
)
_sym_db.RegisterEnumDescriptor(_SSLCERTIFICATETYPE)

SSLCertificateType = enum_type_wrapper.EnumTypeWrapper(_SSLCERTIFICATETYPE)
_SSLCERTIFICATESTATUS = _descriptor.EnumDescriptor(
  name='SSLCertificateStatus',
  full_name='yandex.cloud.cdn.v1.SSLCertificateStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SSL_CERTIFICATE_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5013,
  serialized_end=5100,
)
_sym_db.RegisterEnumDescriptor(_SSLCERTIFICATESTATUS)

SSLCertificateStatus = enum_type_wrapper.EnumTypeWrapper(_SSLCERTIFICATESTATUS)
ORIGIN_PROTOCOL_UNSPECIFIED = 0
HTTP = 1
HTTPS = 2
MATCH = 3
REWRITE_FLAG_UNSPECIFIED = 0
LAST = 1
BREAK = 2
REDIRECT = 3
PERMANENT = 4
SSL_CERTIFICATE_TYPE_UNSPECIFIED = 0
DONT_USE = 1
LETS_ENCRYPT_GCORE = 2
CM = 3
SSL_CERTIFICATE_STATUS_UNSPECIFIED = 0
READY = 1
CREATING = 2



_SECONDARYHOSTNAMES = _descriptor.Descriptor(
  name='SecondaryHostnames',
  full_name='yandex.cloud.cdn.v1.SecondaryHostnames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='yandex.cloud.cdn.v1.SecondaryHostnames.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=128,
)


_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='yandex.cloud.cdn.v1.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.cdn.v1.Resource.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.Resource.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cname', full_name='yandex.cloud.cdn.v1.Resource.cname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.cdn.v1.Resource.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='yandex.cloud.cdn.v1.Resource.updated_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.cdn.v1.Resource.active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='yandex.cloud.cdn.v1.Resource.options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_hostnames', full_name='yandex.cloud.cdn.v1.Resource.secondary_hostnames', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.Resource.origin_group_id', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_name', full_name='yandex.cloud.cdn.v1.Resource.origin_group_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_protocol', full_name='yandex.cloud.cdn.v1.Resource.origin_protocol', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_certificate', full_name='yandex.cloud.cdn.v1.Resource.ssl_certificate', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=559,
)


_RESOURCEOPTIONS_BOOLOPTION = _descriptor.Descriptor(
  name='BoolOption',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.BoolOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.BoolOption.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.BoolOption.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2117,
)

_RESOURCEOPTIONS_STRINGOPTION = _descriptor.Descriptor(
  name='StringOption',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.StringOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringOption.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringOption.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2119,
  serialized_end=2165,
)

_RESOURCEOPTIONS_INT64OPTION = _descriptor.Descriptor(
  name='Int64Option',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.Int64Option',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.Int64Option.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.Int64Option.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2167,
  serialized_end=2212,
)

_RESOURCEOPTIONS_STRINGSLISTOPTION = _descriptor.Descriptor(
  name='StringsListOption',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsListOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsListOption.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsListOption.value', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2214,
  serialized_end=2265,
)

_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY = _descriptor.Descriptor(
  name='ValueEntry',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.ValueEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.ValueEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.ValueEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2386,
  serialized_end=2430,
)

_RESOURCEOPTIONS_STRINGSMAPOPTION = _descriptor.Descriptor(
  name='StringsMapOption',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.value', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2430,
)

_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY = _descriptor.Descriptor(
  name='CustomValuesEntry',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.CustomValuesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.CustomValuesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.CustomValuesEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2563,
  serialized_end=2614,
)

_RESOURCEOPTIONS_CACHINGTIMES = _descriptor.Descriptor(
  name='CachingTimes',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.CachingTimes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='simple_value', full_name='yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.simple_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_values', full_name='yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.custom_values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2433,
  serialized_end=2614,
)

_RESOURCEOPTIONS_EDGECACHESETTINGS = _descriptor.Descriptor(
  name='EdgeCacheSettings',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings.default_value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='values_variant', full_name='yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings.values_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2617,
  serialized_end=2764,
)

_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING = _descriptor.Descriptor(
  name='OneofString',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.OneofString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.OneofString.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.OneofString.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='string_option', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.OneofString.string_option',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2900,
  serialized_end=3072,
)

_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY = _descriptor.Descriptor(
  name='ValueEntry',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.ValueEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.ValueEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.ValueEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3074,
  serialized_end=3192,
)

_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION = _descriptor.Descriptor(
  name='StringVariableMapOption',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.value', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING, _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2767,
  serialized_end=3192,
)

_RESOURCEOPTIONS_QUERYPARAMSOPTIONS = _descriptor.Descriptor(
  name='QueryParamsOptions',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_query_string', full_name='yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions.ignore_query_string', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_params_whitelist', full_name='yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions.query_params_whitelist', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_params_blacklist', full_name='yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions.query_params_blacklist', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query_params_variant', full_name='yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions.query_params_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3195,
  serialized_end=3499,
)

_RESOURCEOPTIONS_REDIRECTOPTIONS = _descriptor.Descriptor(
  name='RedirectOptions',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.RedirectOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redirect_http_to_https', full_name='yandex.cloud.cdn.v1.ResourceOptions.RedirectOptions.redirect_http_to_https', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_https_to_http', full_name='yandex.cloud.cdn.v1.ResourceOptions.RedirectOptions.redirect_https_to_http', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='redirect_variant', full_name='yandex.cloud.cdn.v1.ResourceOptions.RedirectOptions.redirect_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3502,
  serialized_end=3705,
)

_RESOURCEOPTIONS_HOSTOPTIONS = _descriptor.Descriptor(
  name='HostOptions',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.HostOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='yandex.cloud.cdn.v1.ResourceOptions.HostOptions.host', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_host_header', full_name='yandex.cloud.cdn.v1.ResourceOptions.HostOptions.forward_host_header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='host_variant', full_name='yandex.cloud.cdn.v1.ResourceOptions.HostOptions.host_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3708,
  serialized_end=3884,
)

_RESOURCEOPTIONS_COMPRESSIONOPTIONS = _descriptor.Descriptor(
  name='CompressionOptions',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fetch_compressed', full_name='yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions.fetch_compressed', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gzip_on', full_name='yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions.gzip_on', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brotli_compression', full_name='yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions.brotli_compression', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='compression_variant', full_name='yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions.compression_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3887,
  serialized_end=4161,
)

_RESOURCEOPTIONS_REWRITEOPTION = _descriptor.Descriptor(
  name='RewriteOption',
  full_name='yandex.cloud.cdn.v1.ResourceOptions.RewriteOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.ResourceOptions.RewriteOption.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='yandex.cloud.cdn.v1.ResourceOptions.RewriteOption.body', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag', full_name='yandex.cloud.cdn.v1.ResourceOptions.RewriteOption.flag', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4163,
  serialized_end=4257,
)

_RESOURCEOPTIONS = _descriptor.Descriptor(
  name='ResourceOptions',
  full_name='yandex.cloud.cdn.v1.ResourceOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disable_cache', full_name='yandex.cloud.cdn.v1.ResourceOptions.disable_cache', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edge_cache_settings', full_name='yandex.cloud.cdn.v1.ResourceOptions.edge_cache_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='browser_cache_settings', full_name='yandex.cloud.cdn.v1.ResourceOptions.browser_cache_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_http_headers', full_name='yandex.cloud.cdn.v1.ResourceOptions.cache_http_headers', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_params_options', full_name='yandex.cloud.cdn.v1.ResourceOptions.query_params_options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice', full_name='yandex.cloud.cdn.v1.ResourceOptions.slice', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_options', full_name='yandex.cloud.cdn.v1.ResourceOptions.compression_options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_options', full_name='yandex.cloud.cdn.v1.ResourceOptions.redirect_options', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_options', full_name='yandex.cloud.cdn.v1.ResourceOptions.host_options', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_headers', full_name='yandex.cloud.cdn.v1.ResourceOptions.static_headers', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cors', full_name='yandex.cloud.cdn.v1.ResourceOptions.cors', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stale', full_name='yandex.cloud.cdn.v1.ResourceOptions.stale', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_http_methods', full_name='yandex.cloud.cdn.v1.ResourceOptions.allowed_http_methods', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_cache_methods_set', full_name='yandex.cloud.cdn.v1.ResourceOptions.proxy_cache_methods_set', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_proxy_force_ranges', full_name='yandex.cloud.cdn.v1.ResourceOptions.disable_proxy_force_ranges', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_request_headers', full_name='yandex.cloud.cdn.v1.ResourceOptions.static_request_headers', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_server_name', full_name='yandex.cloud.cdn.v1.ResourceOptions.custom_server_name', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_cookie', full_name='yandex.cloud.cdn.v1.ResourceOptions.ignore_cookie', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewrite', full_name='yandex.cloud.cdn.v1.ResourceOptions.rewrite', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEOPTIONS_BOOLOPTION, _RESOURCEOPTIONS_STRINGOPTION, _RESOURCEOPTIONS_INT64OPTION, _RESOURCEOPTIONS_STRINGSLISTOPTION, _RESOURCEOPTIONS_STRINGSMAPOPTION, _RESOURCEOPTIONS_CACHINGTIMES, _RESOURCEOPTIONS_EDGECACHESETTINGS, _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION, _RESOURCEOPTIONS_QUERYPARAMSOPTIONS, _RESOURCEOPTIONS_REDIRECTOPTIONS, _RESOURCEOPTIONS_HOSTOPTIONS, _RESOURCEOPTIONS_COMPRESSIONOPTIONS, _RESOURCEOPTIONS_REWRITEOPTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=4257,
)


_SSLTARGETCERTIFICATE = _descriptor.Descriptor(
  name='SSLTargetCertificate',
  full_name='yandex.cloud.cdn.v1.SSLTargetCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.cdn.v1.SSLTargetCertificate.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.cdn.v1.SSLTargetCertificate.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4260,
  serialized_end=4392,
)


_SSLCERTIFICATE = _descriptor.Descriptor(
  name='SSLCertificate',
  full_name='yandex.cloud.cdn.v1.SSLCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.cdn.v1.SSLCertificate.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.cdn.v1.SSLCertificate.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.cdn.v1.SSLCertificate.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4395,
  serialized_end=4580,
)


_SSLCERTIFICATEDATA = _descriptor.Descriptor(
  name='SSLCertificateData',
  full_name='yandex.cloud.cdn.v1.SSLCertificateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cm', full_name='yandex.cloud.cdn.v1.SSLCertificateData.cm', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ssl_certificate_data_variant', full_name='yandex.cloud.cdn.v1.SSLCertificateData.ssl_certificate_data_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4582,
  serialized_end=4691,
)


_SSLCERTIFICATECMDATA = _descriptor.Descriptor(
  name='SSLCertificateCMData',
  full_name='yandex.cloud.cdn.v1.SSLCertificateCMData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.cdn.v1.SSLCertificateCMData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4693,
  serialized_end=4727,
)

_RESOURCE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESOURCE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESOURCE.fields_by_name['options'].message_type = _RESOURCEOPTIONS
_RESOURCE.fields_by_name['origin_protocol'].enum_type = _ORIGINPROTOCOL
_RESOURCE.fields_by_name['ssl_certificate'].message_type = _SSLCERTIFICATE
_RESOURCEOPTIONS_BOOLOPTION.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_STRINGOPTION.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_INT64OPTION.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_STRINGSLISTOPTION.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY.containing_type = _RESOURCEOPTIONS_STRINGSMAPOPTION
_RESOURCEOPTIONS_STRINGSMAPOPTION.fields_by_name['value'].message_type = _RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY
_RESOURCEOPTIONS_STRINGSMAPOPTION.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY.containing_type = _RESOURCEOPTIONS_CACHINGTIMES
_RESOURCEOPTIONS_CACHINGTIMES.fields_by_name['custom_values'].message_type = _RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY
_RESOURCEOPTIONS_CACHINGTIMES.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_EDGECACHESETTINGS.fields_by_name['value'].message_type = _RESOURCEOPTIONS_CACHINGTIMES
_RESOURCEOPTIONS_EDGECACHESETTINGS.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_EDGECACHESETTINGS.oneofs_by_name['values_variant'].fields.append(
  _RESOURCEOPTIONS_EDGECACHESETTINGS.fields_by_name['value'])
_RESOURCEOPTIONS_EDGECACHESETTINGS.fields_by_name['value'].containing_oneof = _RESOURCEOPTIONS_EDGECACHESETTINGS.oneofs_by_name['values_variant']
_RESOURCEOPTIONS_EDGECACHESETTINGS.oneofs_by_name['values_variant'].fields.append(
  _RESOURCEOPTIONS_EDGECACHESETTINGS.fields_by_name['default_value'])
_RESOURCEOPTIONS_EDGECACHESETTINGS.fields_by_name['default_value'].containing_oneof = _RESOURCEOPTIONS_EDGECACHESETTINGS.oneofs_by_name['values_variant']
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.fields_by_name['value'].message_type = _RESOURCEOPTIONS_STRINGOPTION
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.fields_by_name['values'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.containing_type = _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.oneofs_by_name['string_option'].fields.append(
  _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.fields_by_name['value'])
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.fields_by_name['value'].containing_oneof = _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.oneofs_by_name['string_option']
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.oneofs_by_name['string_option'].fields.append(
  _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.fields_by_name['values'])
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.fields_by_name['values'].containing_oneof = _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING.oneofs_by_name['string_option']
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY.fields_by_name['value'].message_type = _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY.containing_type = _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION.fields_by_name['value'].message_type = _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['ignore_query_string'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['query_params_whitelist'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['query_params_blacklist'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.oneofs_by_name['query_params_variant'].fields.append(
  _RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['ignore_query_string'])
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['ignore_query_string'].containing_oneof = _RESOURCEOPTIONS_QUERYPARAMSOPTIONS.oneofs_by_name['query_params_variant']
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.oneofs_by_name['query_params_variant'].fields.append(
  _RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['query_params_whitelist'])
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['query_params_whitelist'].containing_oneof = _RESOURCEOPTIONS_QUERYPARAMSOPTIONS.oneofs_by_name['query_params_variant']
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.oneofs_by_name['query_params_variant'].fields.append(
  _RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['query_params_blacklist'])
_RESOURCEOPTIONS_QUERYPARAMSOPTIONS.fields_by_name['query_params_blacklist'].containing_oneof = _RESOURCEOPTIONS_QUERYPARAMSOPTIONS.oneofs_by_name['query_params_variant']
_RESOURCEOPTIONS_REDIRECTOPTIONS.fields_by_name['redirect_http_to_https'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS_REDIRECTOPTIONS.fields_by_name['redirect_https_to_http'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS_REDIRECTOPTIONS.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_REDIRECTOPTIONS.oneofs_by_name['redirect_variant'].fields.append(
  _RESOURCEOPTIONS_REDIRECTOPTIONS.fields_by_name['redirect_http_to_https'])
_RESOURCEOPTIONS_REDIRECTOPTIONS.fields_by_name['redirect_http_to_https'].containing_oneof = _RESOURCEOPTIONS_REDIRECTOPTIONS.oneofs_by_name['redirect_variant']
_RESOURCEOPTIONS_REDIRECTOPTIONS.oneofs_by_name['redirect_variant'].fields.append(
  _RESOURCEOPTIONS_REDIRECTOPTIONS.fields_by_name['redirect_https_to_http'])
_RESOURCEOPTIONS_REDIRECTOPTIONS.fields_by_name['redirect_https_to_http'].containing_oneof = _RESOURCEOPTIONS_REDIRECTOPTIONS.oneofs_by_name['redirect_variant']
_RESOURCEOPTIONS_HOSTOPTIONS.fields_by_name['host'].message_type = _RESOURCEOPTIONS_STRINGOPTION
_RESOURCEOPTIONS_HOSTOPTIONS.fields_by_name['forward_host_header'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS_HOSTOPTIONS.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_HOSTOPTIONS.oneofs_by_name['host_variant'].fields.append(
  _RESOURCEOPTIONS_HOSTOPTIONS.fields_by_name['host'])
_RESOURCEOPTIONS_HOSTOPTIONS.fields_by_name['host'].containing_oneof = _RESOURCEOPTIONS_HOSTOPTIONS.oneofs_by_name['host_variant']
_RESOURCEOPTIONS_HOSTOPTIONS.oneofs_by_name['host_variant'].fields.append(
  _RESOURCEOPTIONS_HOSTOPTIONS.fields_by_name['forward_host_header'])
_RESOURCEOPTIONS_HOSTOPTIONS.fields_by_name['forward_host_header'].containing_oneof = _RESOURCEOPTIONS_HOSTOPTIONS.oneofs_by_name['host_variant']
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['fetch_compressed'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['gzip_on'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['brotli_compression'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.oneofs_by_name['compression_variant'].fields.append(
  _RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['fetch_compressed'])
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['fetch_compressed'].containing_oneof = _RESOURCEOPTIONS_COMPRESSIONOPTIONS.oneofs_by_name['compression_variant']
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.oneofs_by_name['compression_variant'].fields.append(
  _RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['gzip_on'])
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['gzip_on'].containing_oneof = _RESOURCEOPTIONS_COMPRESSIONOPTIONS.oneofs_by_name['compression_variant']
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.oneofs_by_name['compression_variant'].fields.append(
  _RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['brotli_compression'])
_RESOURCEOPTIONS_COMPRESSIONOPTIONS.fields_by_name['brotli_compression'].containing_oneof = _RESOURCEOPTIONS_COMPRESSIONOPTIONS.oneofs_by_name['compression_variant']
_RESOURCEOPTIONS_REWRITEOPTION.fields_by_name['flag'].enum_type = _REWRITEFLAG
_RESOURCEOPTIONS_REWRITEOPTION.containing_type = _RESOURCEOPTIONS
_RESOURCEOPTIONS.fields_by_name['disable_cache'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS.fields_by_name['edge_cache_settings'].message_type = _RESOURCEOPTIONS_EDGECACHESETTINGS
_RESOURCEOPTIONS.fields_by_name['browser_cache_settings'].message_type = _RESOURCEOPTIONS_INT64OPTION
_RESOURCEOPTIONS.fields_by_name['cache_http_headers'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS.fields_by_name['query_params_options'].message_type = _RESOURCEOPTIONS_QUERYPARAMSOPTIONS
_RESOURCEOPTIONS.fields_by_name['slice'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS.fields_by_name['compression_options'].message_type = _RESOURCEOPTIONS_COMPRESSIONOPTIONS
_RESOURCEOPTIONS.fields_by_name['redirect_options'].message_type = _RESOURCEOPTIONS_REDIRECTOPTIONS
_RESOURCEOPTIONS.fields_by_name['host_options'].message_type = _RESOURCEOPTIONS_HOSTOPTIONS
_RESOURCEOPTIONS.fields_by_name['static_headers'].message_type = _RESOURCEOPTIONS_STRINGSMAPOPTION
_RESOURCEOPTIONS.fields_by_name['cors'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS.fields_by_name['stale'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS.fields_by_name['allowed_http_methods'].message_type = _RESOURCEOPTIONS_STRINGSLISTOPTION
_RESOURCEOPTIONS.fields_by_name['proxy_cache_methods_set'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS.fields_by_name['disable_proxy_force_ranges'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS.fields_by_name['static_request_headers'].message_type = _RESOURCEOPTIONS_STRINGSMAPOPTION
_RESOURCEOPTIONS.fields_by_name['custom_server_name'].message_type = _RESOURCEOPTIONS_STRINGOPTION
_RESOURCEOPTIONS.fields_by_name['ignore_cookie'].message_type = _RESOURCEOPTIONS_BOOLOPTION
_RESOURCEOPTIONS.fields_by_name['rewrite'].message_type = _RESOURCEOPTIONS_REWRITEOPTION
_SSLTARGETCERTIFICATE.fields_by_name['type'].enum_type = _SSLCERTIFICATETYPE
_SSLTARGETCERTIFICATE.fields_by_name['data'].message_type = _SSLCERTIFICATEDATA
_SSLCERTIFICATE.fields_by_name['type'].enum_type = _SSLCERTIFICATETYPE
_SSLCERTIFICATE.fields_by_name['status'].enum_type = _SSLCERTIFICATESTATUS
_SSLCERTIFICATE.fields_by_name['data'].message_type = _SSLCERTIFICATEDATA
_SSLCERTIFICATEDATA.fields_by_name['cm'].message_type = _SSLCERTIFICATECMDATA
_SSLCERTIFICATEDATA.oneofs_by_name['ssl_certificate_data_variant'].fields.append(
  _SSLCERTIFICATEDATA.fields_by_name['cm'])
_SSLCERTIFICATEDATA.fields_by_name['cm'].containing_oneof = _SSLCERTIFICATEDATA.oneofs_by_name['ssl_certificate_data_variant']
DESCRIPTOR.message_types_by_name['SecondaryHostnames'] = _SECONDARYHOSTNAMES
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.message_types_by_name['ResourceOptions'] = _RESOURCEOPTIONS
DESCRIPTOR.message_types_by_name['SSLTargetCertificate'] = _SSLTARGETCERTIFICATE
DESCRIPTOR.message_types_by_name['SSLCertificate'] = _SSLCERTIFICATE
DESCRIPTOR.message_types_by_name['SSLCertificateData'] = _SSLCERTIFICATEDATA
DESCRIPTOR.message_types_by_name['SSLCertificateCMData'] = _SSLCERTIFICATECMDATA
DESCRIPTOR.enum_types_by_name['OriginProtocol'] = _ORIGINPROTOCOL
DESCRIPTOR.enum_types_by_name['RewriteFlag'] = _REWRITEFLAG
DESCRIPTOR.enum_types_by_name['SSLCertificateType'] = _SSLCERTIFICATETYPE
DESCRIPTOR.enum_types_by_name['SSLCertificateStatus'] = _SSLCERTIFICATESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SecondaryHostnames = _reflection.GeneratedProtocolMessageType('SecondaryHostnames', (_message.Message,), {
  'DESCRIPTOR' : _SECONDARYHOSTNAMES,
  '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.SecondaryHostnames)
  })
_sym_db.RegisterMessage(SecondaryHostnames)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.Resource)
  })
_sym_db.RegisterMessage(Resource)

ResourceOptions = _reflection.GeneratedProtocolMessageType('ResourceOptions', (_message.Message,), {

  'BoolOption' : _reflection.GeneratedProtocolMessageType('BoolOption', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_BOOLOPTION,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.BoolOption)
    })
  ,

  'StringOption' : _reflection.GeneratedProtocolMessageType('StringOption', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_STRINGOPTION,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.StringOption)
    })
  ,

  'Int64Option' : _reflection.GeneratedProtocolMessageType('Int64Option', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_INT64OPTION,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.Int64Option)
    })
  ,

  'StringsListOption' : _reflection.GeneratedProtocolMessageType('StringsListOption', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_STRINGSLISTOPTION,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.StringsListOption)
    })
  ,

  'StringsMapOption' : _reflection.GeneratedProtocolMessageType('StringsMapOption', (_message.Message,), {

    'ValueEntry' : _reflection.GeneratedProtocolMessageType('ValueEntry', (_message.Message,), {
      'DESCRIPTOR' : _RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY,
      '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.ValueEntry)
      })
    ,
    'DESCRIPTOR' : _RESOURCEOPTIONS_STRINGSMAPOPTION,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption)
    })
  ,

  'CachingTimes' : _reflection.GeneratedProtocolMessageType('CachingTimes', (_message.Message,), {

    'CustomValuesEntry' : _reflection.GeneratedProtocolMessageType('CustomValuesEntry', (_message.Message,), {
      'DESCRIPTOR' : _RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY,
      '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.CustomValuesEntry)
      })
    ,
    'DESCRIPTOR' : _RESOURCEOPTIONS_CACHINGTIMES,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.CachingTimes)
    })
  ,

  'EdgeCacheSettings' : _reflection.GeneratedProtocolMessageType('EdgeCacheSettings', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_EDGECACHESETTINGS,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings)
    })
  ,

  'StringVariableMapOption' : _reflection.GeneratedProtocolMessageType('StringVariableMapOption', (_message.Message,), {

    'OneofString' : _reflection.GeneratedProtocolMessageType('OneofString', (_message.Message,), {
      'DESCRIPTOR' : _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING,
      '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.OneofString)
      })
    ,

    'ValueEntry' : _reflection.GeneratedProtocolMessageType('ValueEntry', (_message.Message,), {
      'DESCRIPTOR' : _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY,
      '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.ValueEntry)
      })
    ,
    'DESCRIPTOR' : _RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption)
    })
  ,

  'QueryParamsOptions' : _reflection.GeneratedProtocolMessageType('QueryParamsOptions', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_QUERYPARAMSOPTIONS,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions)
    })
  ,

  'RedirectOptions' : _reflection.GeneratedProtocolMessageType('RedirectOptions', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_REDIRECTOPTIONS,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.RedirectOptions)
    })
  ,

  'HostOptions' : _reflection.GeneratedProtocolMessageType('HostOptions', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_HOSTOPTIONS,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.HostOptions)
    })
  ,

  'CompressionOptions' : _reflection.GeneratedProtocolMessageType('CompressionOptions', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_COMPRESSIONOPTIONS,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions)
    })
  ,

  'RewriteOption' : _reflection.GeneratedProtocolMessageType('RewriteOption', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEOPTIONS_REWRITEOPTION,
    '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions.RewriteOption)
    })
  ,
  'DESCRIPTOR' : _RESOURCEOPTIONS,
  '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOptions)
  })
_sym_db.RegisterMessage(ResourceOptions)
_sym_db.RegisterMessage(ResourceOptions.BoolOption)
_sym_db.RegisterMessage(ResourceOptions.StringOption)
_sym_db.RegisterMessage(ResourceOptions.Int64Option)
_sym_db.RegisterMessage(ResourceOptions.StringsListOption)
_sym_db.RegisterMessage(ResourceOptions.StringsMapOption)
_sym_db.RegisterMessage(ResourceOptions.StringsMapOption.ValueEntry)
_sym_db.RegisterMessage(ResourceOptions.CachingTimes)
_sym_db.RegisterMessage(ResourceOptions.CachingTimes.CustomValuesEntry)
_sym_db.RegisterMessage(ResourceOptions.EdgeCacheSettings)
_sym_db.RegisterMessage(ResourceOptions.StringVariableMapOption)
_sym_db.RegisterMessage(ResourceOptions.StringVariableMapOption.OneofString)
_sym_db.RegisterMessage(ResourceOptions.StringVariableMapOption.ValueEntry)
_sym_db.RegisterMessage(ResourceOptions.QueryParamsOptions)
_sym_db.RegisterMessage(ResourceOptions.RedirectOptions)
_sym_db.RegisterMessage(ResourceOptions.HostOptions)
_sym_db.RegisterMessage(ResourceOptions.CompressionOptions)
_sym_db.RegisterMessage(ResourceOptions.RewriteOption)

SSLTargetCertificate = _reflection.GeneratedProtocolMessageType('SSLTargetCertificate', (_message.Message,), {
  'DESCRIPTOR' : _SSLTARGETCERTIFICATE,
  '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.SSLTargetCertificate)
  })
_sym_db.RegisterMessage(SSLTargetCertificate)

SSLCertificate = _reflection.GeneratedProtocolMessageType('SSLCertificate', (_message.Message,), {
  'DESCRIPTOR' : _SSLCERTIFICATE,
  '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.SSLCertificate)
  })
_sym_db.RegisterMessage(SSLCertificate)

SSLCertificateData = _reflection.GeneratedProtocolMessageType('SSLCertificateData', (_message.Message,), {
  'DESCRIPTOR' : _SSLCERTIFICATEDATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.SSLCertificateData)
  })
_sym_db.RegisterMessage(SSLCertificateData)

SSLCertificateCMData = _reflection.GeneratedProtocolMessageType('SSLCertificateCMData', (_message.Message,), {
  'DESCRIPTOR' : _SSLCERTIFICATECMDATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.SSLCertificateCMData)
  })
_sym_db.RegisterMessage(SSLCertificateCMData)


DESCRIPTOR._options = None
_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY._options = None
_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY._options = None
_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/origin_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/origin_group.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&yandex/cloud/cdn/v1/origin_group.proto\x12\x13yandex.cloud.cdn.v1\x1a yandex/cloud/cdn/v1/origin.proto\"z\n\x0bOriginGroup\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08use_next\x18\x04 \x01(\x08\x12,\n\x07origins\x18\x05 \x03(\x0b\x32\x1b.yandex.cloud.cdn.v1.OriginBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.DESCRIPTOR,])




_ORIGINGROUP = _descriptor.Descriptor(
  name='OriginGroup',
  full_name='yandex.cloud.cdn.v1.OriginGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.cdn.v1.OriginGroup.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.OriginGroup.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.cdn.v1.OriginGroup.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_next', full_name='yandex.cloud.cdn.v1.OriginGroup.use_next', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origins', full_name='yandex.cloud.cdn.v1.OriginGroup.origins', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=219,
)

_ORIGINGROUP.fields_by_name['origins'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGIN
DESCRIPTOR.message_types_by_name['OriginGroup'] = _ORIGINGROUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OriginGroup = _reflection.GeneratedProtocolMessageType('OriginGroup', (_message.Message,), {
  'DESCRIPTOR' : _ORIGINGROUP,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.OriginGroup)
  })
_sym_db.RegisterMessage(OriginGroup)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
